Серверное приложение
=============================================

Серверное приложение мессенджера. Обрабатывает подключения клиентов и обменивается с ними сообщениями. Имеет графический и консольный интерфейсы администратора. 

**Запуск сервера**

Запуск сервера выполняется из корневой директории путем вызова модуля ``server.py`` из командной строки с параметрами: 

1. -p / --port - Порт, на котором принимаются соединения
2. -a / --host - Адрес, с которого принимаются соединения.
3. -s / --silent Запуск без графической оболочки.

*В данном режиме не поддерживается ввод команд.*

Примеры использования:

``python server.py -p 8080``

*Запуск сервера на порту 8080*

``python server.py -a localhost``

*Запуск сервера принимающего только соединения с localhost*

``python server.py -s``

*Запуск без графической оболочки*

**Администрирование**
Ведение пользователей выполняется в графической оболочке, создание может выполняться в интерфейсе командной строки.
Для создания пользователя из интерфейса командной строки необходимо вызвать модуль ``server.py``, указав команду ``user_add`` с параметрами:
1. -l / --login - Логин пользователя;
2. -p / --password - Пароль.

``python server.py user_add -l test2 -p 123``

*Создание пользователя test2 с паролем 123*

server.py
~~~~~~~~~

Запускаемый модуль,содержит парсер аргументов командной строки и функционал инициализации приложения.
